@@ -15,19 +15,23 @@
 
 #include <QStringList>
 
-class TopLevel;
+class QMediaPlayer;
 
-namespace Phonon
+class SoundFactoryCallbacks
 {
-      class MediaObject;
-}
+public:
+  virtual ~SoundFactoryCallbacks() {};
+  virtual bool isSoundEnabled() const = 0;
+  virtual void registerLanguage(const QString &code, const QString &soundFile, bool enabled) = 0;
+};
 
 class SoundFactory
 {
 public:
-
-  explicit SoundFactory(TopLevel *parent);
+  explicit SoundFactory(SoundFactoryCallbacks *callbacks);
   ~SoundFactory();
+  SoundFactory(const SoundFactory &) = delete;
+  SoundFactory &operator=(const SoundFactory &) = delete;
 
   bool loadLanguage(const QString &selectedLanguageFile);
   void playSound(const QString &soundRef) const;
@@ -37,14 +41,15 @@ public:
   void registerLanguages();
 
 private:
+  SoundFactoryCallbacks *m_callbacks;
+
   QString currentSndFile;		// The current language
 
   int sounds;				// Number of sounds
   QStringList namesList,		// List of sound names
               filesList;           // List of sound files associated with each sound name
 
-  TopLevel *topLevel;		// Top-level window
-  Phonon::MediaObject *player;  // Sound player
+  QMediaPlayer *player;
 };
 
 #endif
