@@ -16,8 +16,6 @@
 #include <QPainter>
 #include <QSvgRenderer>
 
-#include <kdeversion.h>
-
 static QImage toImage(const QString &element, int width, int height, QSvgRenderer *renderer)
 {
   QImage img(width, height, QImage::Format_ARGB32_Premultiplied);
@@ -73,7 +71,7 @@ QRectF ToDraw::clippedRectAt(const QPointF &somePos) const
   if (m_beingDragged)
     return unclippedRect();
 
-  QRectF backgroundRect = renderer()->boundsOnElement(QLatin1String( "background" ));
+  QRectF backgroundRect = renderer()->boundsOnElement(QStringLiteral( "background" ));
   backgroundRect.translate(-somePos);
   backgroundRect = transform().inverted().map(backgroundRect).boundingRect();
 
